==> indexer-0.0.4.tgz: package/README.md <==
# Indexer

Indexer is a half-interval search index that can index both string and numeric values. This is the index being used by fakedb.

## Installation

```
npm install indexer
```

## Example Code

``` js
var Indexer = require('indexer');

var users = [
  { name: 'sheryl', age: 33 },
  { name: 'jaydee', age: 32 },
  { name: 'addie', age: 0.33 },
  { name: 'jayden', age: 31 },
  { name: 'adrienne', age: 13 },
  { name: 'jaime', age: 12 },
  { name: 'james', age: 11 },
  { name: 'adelle', age: 24 },
  { name: 'sheila', age: 22 },
  { name: 'shermaine', age: 19 }
];

function populateIndex(index, field, records) {
  for (var i = 0, n = records.length; i < n; ++i) {
    index.add(records[i][field], i);
  }
}

var index = Indexer.create('name_index');

populateIndex(index, 'name', users);

console.log(
  'Matching entries for [jaydee]: ' + index.search('jaydee') + '\n' +
  'Matching entries for [adrienne]: ' + index.search('adrienne') + '\n' +
  'Matching entries for [shermaine]: ' + index.search('shermaine')
);

var numeric_index = Indexer.create({
  name: 'age_index',
  type: 'numeric'
});

populateIndex(numeric_index, 'age', users);

console.log(
  'Matching entries for [19]: ' + numeric_index.search(19) + '\n' +
  'Matching entries for [21]: ' + numeric_index.search(21) + '\n' +
  'Matching entries for [33]: ' + numeric_index.search(33)
);
```

## License

(The MIT License)

Copyright (c) 2011 Jesus A. Domingo <jesus.domingo@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the 'Software'), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> indexer-1.0.2.tgz: package/README.md <==
# Indexer

Indexer is a half-interval search index that can index both string and numeric values. This is the index being used by fakedb.

## Installation

```
npm install indexer
```

## Example Code

``` js
var Indexer = require('indexer');

var users = [
  { name: 'sheryl', age: 33 },
  { name: 'jaydee', age: 32 },
  { name: 'addie', age: 0.33 },
  { name: 'jayden', age: 31 },
  { name: 'adrienne', age: 13 },
  { name: 'jaime', age: 12 },
  { name: 'james', age: 11 },
  { name: 'adelle', age: 24 },
  { name: 'sheila', age: 22 },
  { name: 'shermaine', age: 19 }
];

function populateIndex(index, field, records) {
  for (var i = 0, n = records.length; i < n; ++i) {
    index.add(records[i][field], i);
  }
}

var index = Indexer.create('name');

populateIndex(index, 'name', users);

console.log(
  'Matching entries for [jaydee]: ' + index.search('jaydee') + '\n' +
  'Matching entries for [adrienne]: ' + index.search('adrienne') + '\n' +
  'Matching entries for [shermaine]: ' + index.search('shermaine')
);
```

## License

(The MIT License)

Copyright (c) 2011 Jesus A. Domingo <jesus.domingo@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the 'Software'), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
